@@ -20,20 +20,20 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <libgda/gda-intl.h>
+#include <glib/gi18n-lib.h>
 #include <stdlib.h>
 #include <string.h>
 #include "gda-bdb.h"
 
-GdaError *
+GdaConnectionEvent *
 gda_bdb_make_error (int ret)
 {
-	GdaError *error = gda_error_new ();
+	GdaConnectionEvent *error = gda_connection_event_new (GDA_CONNECTION_EVENT_ERROR);
 
-	gda_error_set_description (error, db_strerror (ret));
-	gda_error_set_number (error, -1);
-	gda_error_set_source (error, "gda-bdb");
-	gda_error_set_sqlstate (error, _("Not available"));
+	gda_connection_event_set_description (error, db_strerror (ret));
+	gda_connection_event_set_code (error, -1);
+	gda_connection_event_set_source (error, "gda-bdb");
+	gda_connection_event_set_sqlstate (error, _("Not available"));
 	
 	return error;
 }
